==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/config/TType.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;

namespace com.db4o.config {

	/// <exclude />
    public class TType : ObjectConstructor {
		
		static readonly Class _stringClass = Class.getClassForType(typeof(String));
      
        public void onActivate(ObjectContainer objectContainer, object obj, object members) {
        }
      
        public Object onInstantiate(ObjectContainer objectContainer, object obj) {
            try { 
                return Class.forName((String)obj).getNetType();
            }  catch (Exception exception) { 
                return null;
            }
        }
      
        public Object onStore(ObjectContainer objectContainer, object obj) {
            return Class.getClassForType((System.Type)obj).getName(); 
        }
      
        public Class storedClass() {
            return _stringClass;
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/config/TType.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;

namespace com.db4o.config {

	/// <exclude />
    public class TType : ObjectConstructor {
		
		static readonly Class _stringClass = Class.GetClassForType(typeof(String));
      
        public void OnActivate(ObjectContainer objectContainer, object obj, object members) {
        }
      
        public Object OnInstantiate(ObjectContainer objectContainer, object obj) {
            try { 
                return Class.ForName((String)obj).GetNetType();
            }  catch (Exception exception) { 
                return null;
            }
        }
      
        public Object OnStore(ObjectContainer objectContainer, object obj) {
            return Class.GetClassForType((System.Type)obj).GetName(); 
        }
      
        public Class StoredClass() {
            return _stringClass;
        }
    }
}
